@@ -3,7 +3,7 @@
 #
 #  __init__.py
 #
-#  Copyright 2016 Jelle Smet <development@smetj.net>
+#  Copyright 2018 Jelle Smet <development@smetj.net>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -22,4 +22,4 @@
 #
 #
 
-from httpinserver import HTTPInServer
+from .httpserver import HTTPServer
